@@ -11,7 +11,7 @@ impl Record {
     const SLEEP_DURATION: Duration = Duration::from_millis(1000);
 
     pub async fn record(config: CliRecordConfig) {
-        Stubr::record_with(config.into());
+        let _recorder = Stubr::record_with(config.into());
         loop { async_std::task::sleep(Self::SLEEP_DURATION).await; }
     }
 }
\ No newline at end of file
